@@ -1,19 +1,19 @@
 bsnVaryNvar <-
-function (m = 100, nvar = nvmax:50, nvmax = 3, method = "exhaustive", 
-          intercept = TRUE, plotit = TRUE, xlab = "# of variables from which to select", 
-          ylab = "p-values for t-statistics", main = paste("Select 'best'", 
-                                                           nvmax, "variables"), details = FALSE, really.big = TRUE, 
-          smooth = TRUE, ...) 
+function (m = 100, nvar = nvmax:50, nvmax = 3, method = "exhaustive",
+          intercept = TRUE, plotit = TRUE, xlab = "# of variables from which to select",
+          ylab = "p-values for t-statistics", main = paste("Select 'best'",
+                                                           nvmax, "variables"), details = FALSE, really.big = TRUE,
+          smooth = TRUE, ...)
 {
-  if (nvar[1] < nvmax) 
-    stop(paste("Initial value of 'num' must be at least", 
+  if (nvar[1] < nvmax)
+    stop(paste("Initial value of 'num' must be at least",
                nvmax))
   leaps.out <- try(requireNamespace("leaps"), silent = TRUE)
   if (!is.logical(leaps.out) | (leaps.out == FALSE)) {
     print("Error: package leaps is not installed properly")
     return()
   }
-  quantreg.out <- try(requireNamespace("quantreg"), silent = TRUE)
+  qgam.out <- try(requireNamespace("qgam"), silent = TRUE)
   best <- matrix(0, nrow = length(nvar), ncol = nvmax)
   if (details) {
     bestCoef <- bestSE <- best
@@ -21,9 +21,9 @@ function (m = 100, nvar = nvmax:50, nvmax = 3, method = "exhaustive",
   k <- 0
   for (i in nvar) {
     k <- k + 1
-    obj <- bestsetNoise(m = 100, n = i, nvmax = nvmax, intercept = intercept, 
+    obj <- bestsetNoise(m = 100, n = i, nvmax = nvmax, intercept = intercept,
                         print.summary = FALSE, method = method, really.big = really.big)
-    if (intercept) 
+    if (intercept)
       bmat <- coef(summary(obj$best))[2:(nvmax + 1), ]
     else bmat <- coef(summary(obj$best))[1:nvmax, ]
     best[k, ] <- bmat[, 4]
@@ -37,19 +37,20 @@ function (m = 100, nvar = nvmax:50, nvmax = 3, method = "exhaustive",
     x <- rep(nvar, nvmax)
     clogy <- -log(-log(v))
     xlim <- c(0, max(nvar) + 1)
-    plot(x, clogy, yaxt = "n", xlab = xlab, ylab = ylab, 
+    plot(x, clogy, yaxt = "n", xlab = xlab, ylab = ylab,
          col = "gray30", xlim = xlim, xaxs = "i", xaxt = "n", ...)
     pval <- c(0.001, 0.01, 0.05, 0.25, 0.5, 0.75, 0.95)
     g <- -log(-log(pval))
-    if (smooth) 
-      if (quantreg.out) {
-        mod.ns <- quantreg::rq(clogy ~ splines::ns(log(x), 4), 
-                               tau = 0.5)
-        hat <- quantreg::predict.rq(mod.ns)[1:length(nvar)]
+    if (smooth)
+      if (qgam.out) {
+          mod.ns <- qgam::qgam(clogy ~ s(logx),
+                               data=data.frame(clogy=clogy, logx=log(x)),
+                               qu = 0.5)
+        hat <- predict(mod.ns)[1:length(nvar)]
         lines(nvar, hat, col = "gray40", lwd = 1.5)
       }
     else {
-      print("Error: package quantreg is not installed properly,")
+      print("Error: package qgam is not installed properly,")
       print("or not installed. Unable to fit smooth curve")
     }
     axis(1, at = nvar, tck = -0.012, labels = FALSE)
@@ -57,7 +58,7 @@ function (m = 100, nvar = nvmax:50, nvmax = 3, method = "exhaustive",
     axis(2, at = g, labels = paste(pval), pos = 0, tck = -0.02, las=1)
     title(main = main, cex.main = 1.1, line=0.25)
   }
-  if (details) 
+  if (details)
     list(coef = bestCoef, SE = bestSE, pval = best)
   else invisible(best)
 }
